# submitter.py

import requests

def submit(id_student, name, assignment_name, question_name, code, result):
    data = {
        "id": id_student,
        "name": name,
        "assignment_name": assignment_name,
        "question_name": question_name,
        "code": code,
        "result": result
    }

    r = requests.post('https://rea-submitter.fly.dev/submission/submit/bquery', json=data)
    if r.status_code == 200:
        return 'Assignment successfully submitted'
    else:
        return 'Failed to submit assignment'


from setuptools import setup, find_packages

setup(
    name='rggrader',
    version='0.1.0',
    description='Submisiion tool for REA course',
    author='Aditira Jamhuri',
    author_email='aditira.jamhuri@ruangguru.com',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
)